# Uploading AI Agents Through the API
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-using-api#overview)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-using-api#prerequisites)
  * [Activating the API](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-using-api#activating-the-api)
  * [Authentication](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-using-api#authentication)
  * [Endpoint](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-using-api#endpoint)
  * [API Request](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-using-api#api-request)
  * [Linking Discovered Items to Fact Sheets](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-using-api#linking-discovered-items-to-fact-sheets)
  * [Viewing Synchronization Logs](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-using-api#viewing-synchronization-logs)
  * [Deactivating the API](https://help.sap.com/docs/leanix/ea/discovering-ai-agents-using-api#deactivating-the-api)


Upload AI agent cards to SAP LeanIX using the AI Agent API. Preview uploaded AI agents in the AI discovery inbox and add relevant fact sheets to your workspace.
